@@ -391,6 +391,14 @@ class MotionProgram(object):
             wait_cmd.value = value
         self.addCommand(wait_cmd, self.__MotionSpec.WAIT)
 
+    def addSet(self, path, value):
+        set_cmd = self.__MotionSpec.Set()
+        if path is not None:
+            set_cmd.path = path
+            set_cmd.value = value
+        self.addCommand(set_cmd, self.__MotionSpec.SET)
+
+
     def generateMessage(self, program_name='Undefined', system_id=0):
         self.__motion_program.name = program_name
         self.__motion_program.id = self.__id
